==> apache-ranger-2.1.0.tar.gz: apache-ranger-2.1.0/security-admin/src/main/webapp/scripts/collection_bases/VXModuleDefListBase.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


define(function(require){
	'use strict';

	var XABaseCollection	= require('collections/XABaseCollection');
	var XAGlobals			= require('utils/XAGlobals');
	var VXModuleDef			= require('models/VXModuleDef');

	var VXModuleDefListBase = XABaseCollection.extend(
	/** @lends VXModuleDefListBase.prototype */
	{
		url: XAGlobals.baseURL + 'xusers/permission',

		model : VXModuleDef,

		/**
		 * VXModuleDefListBase initialize method
		 * @augments XABaseCollection
		 * @constructs
		 */
		initialize : function() {
			this.modelName = 'VXModuleDef';
			this.modelAttrName = 'vXModuleDef';
			this.bindErrorEvents();
		},
			/**
		 * override the parseRecords of PageableCollection for our use
		 */
		/*parseRecords : function(resp, options){
			return resp;
		}*/
	},{
		// static class members
		/**
		* Table Cols to be passed to Backgrid
		* UI has to use this as base and extend this.
		*
		*/

		tableCols : {}

	});

    return VXModuleDefListBase;
});

==> apache-ranger-2.7.0.tar.gz: apache-ranger-2.7.0/security-admin/src/main/webapp/scripts/collection_bases/VXModuleDefListBase.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


define(function(require){
	'use strict';

	var XABaseCollection	= require('collections/XABaseCollection');
	var XAGlobals			= require('utils/XAGlobals');
	var VXModuleDef			= require('models/VXModuleDef');

	var VXModuleDefListBase = XABaseCollection.extend(
	/** @lends VXModuleDefListBase.prototype */
	{
		url: XAGlobals.baseURL + 'xusers/permissionlist',

		model : VXModuleDef,

		/**
		 * VXModuleDefListBase initialize method
		 * @augments XABaseCollection
		 * @constructs
		 */
		initialize : function() {
			this.modelName = 'vXModulePermissionList';
			this.modelAttrName = 'vXModulePermissionList';
			this.bindErrorEvents();
		},
			/**
		 * override the parseRecords of PageableCollection for our use
		 */
		/*parseRecords : function(resp, options){
			return resp;
		}*/
	},{
		// static class members
		/**
		* Table Cols to be passed to Backgrid
		* UI has to use this as base and extend this.
		*
		*/

		tableCols : {}

	});

    return VXModuleDefListBase;
});
